@@ -1,7 +1,7 @@
 #### Pipeline Functions ####
 
 
-# `%>%`=dplyr::`%>%`
+# `%>%` = dplyr::`%>%`
 
 
 #' Paste strings together.
@@ -20,7 +20,7 @@
 #' "Q" %^% 1:5 %^% letters[1:5]
 #'
 #' @export
-`%^%`=function(x, y) {
+`%^%` = function(x, y) {
   paste0(x, y)
 }
 
@@ -33,14 +33,14 @@
 #' @return A vector of \code{TRUE} or \code{FALSE}.
 #'
 #' @examples
-#' data=data.table(ID=1:10, X=sample(1:10, 10))
+#' data = data.table(ID=1:10, X=sample(1:10, 10))
 #' data
 #' data[ID %notin% c(1, 3, 5, 7, 9)]
 #'
 #' @seealso \code{\link[base:match]{\%in\%}}
 #'
 #' @export
-`%notin%`=function(x, vector) {
+`%notin%` = function(x, vector) {
   match(x, vector, nomatch=0) == 0
 }
 
@@ -61,7 +61,7 @@
 #' \code{\link{\%partin\%}}
 #'
 #' @export
-`%allin%`=function(x, vector) {
+`%allin%` = function(x, vector) {
   all(x %in% vector)
 }
 
@@ -82,7 +82,7 @@
 #' \code{\link{\%partin\%}}
 #'
 #' @export
-`%anyin%`=function(x, vector) {
+`%anyin%` = function(x, vector) {
   any(x %in% vector)
 }
 
@@ -103,7 +103,7 @@
 #' \code{\link{\%partin\%}}
 #'
 #' @export
-`%nonein%`=function(x, vector) {
+`%nonein%` = function(x, vector) {
   !any(x %in% vector)
 }
 
@@ -126,7 +126,7 @@
 #' \code{\link{\%nonein\%}}
 #'
 #' @export
-`%partin%`=function(pattern, vector) {
+`%partin%` = function(pattern, vector) {
   any(grepl(pattern, vector, perl=TRUE))
 }
 
@@ -151,22 +151,22 @@
 #' @seealso \code{\link{pkg_install_suggested}}
 #'
 #' @export
-pkg_depend=function(pkgs, excludes=NULL) {
-  default.pkgs=c("base", "boot", "class",
-                 "cluster", "codetools", "compiler",
-                 "datasets", "foreign", "graphics",
-                 "grDevices", "grid", "KernSmooth",
-                 "lattice", "MASS", "Matrix",
-                 "methods", "mgcv", "nlme",
-                 "nnet", "parallel", "rpart",
-                 "spatial", "splines", "stats",
-                 "stats4", "survival", "tcltk",
-                 "tools", "translations", "utils")
-  exclude.pkgs=default.pkgs
+pkg_depend = function(pkgs, excludes=NULL) {
+  default.pkgs = c("base", "boot", "class",
+                   "cluster", "codetools", "compiler",
+                   "datasets", "foreign", "graphics",
+                   "grDevices", "grid", "KernSmooth",
+                   "lattice", "MASS", "Matrix",
+                   "methods", "mgcv", "nlme",
+                   "nnet", "parallel", "rpart",
+                   "spatial", "splines", "stats",
+                   "stats4", "survival", "tcltk",
+                   "tools", "translations", "utils")
+  exclude.pkgs = default.pkgs
   for(ex in excludes)
-    exclude.pkgs=union(exclude.pkgs, unlist(tools::package_dependencies(ex, recursive=TRUE)))
+    exclude.pkgs = union(exclude.pkgs, unlist(tools::package_dependencies(ex, recursive=TRUE)))
   for(pkg in pkgs)
-    pkgs=union(pkgs, unlist(tools::package_dependencies(pkg, recursive=TRUE)))
+    pkgs = union(pkgs, unlist(tools::package_dependencies(pkg, recursive=TRUE)))
   return(sort(setdiff(pkgs, exclude.pkgs)))
 }
 
@@ -186,9 +186,9 @@ pkg_depend=function(pkgs, excludes=NULL) {
 #' @seealso \code{\link{pkg_depend}}
 #'
 #' @export
-pkg_install_suggested=function(by) {
+pkg_install_suggested = function(by) {
   if(missing(by)) {
-    pkgs.suggests="
+    pkgs.suggests = "
     rstudioapi, devtools, pacman,
     tidyverse, ggstatsplot, jmv,
     dplyr, tidyr, stringr, forcats, data.table,
@@ -215,10 +215,10 @@ pkg_install_suggested=function(by) {
     cat("\n")
     Print(pkgs.suggests)
     cat("\n")
-    yesno=utils::menu(title="All these packages would be installed. Do you want to install them?",
-                      choices=c("Yes", "No"))
+    yesno = utils::menu(title="All these packages would be installed. Do you want to install them?",
+                        choices=c("Yes", "No"))
     if(yesno==1) {
-      pkgs.suggests=pkgs.suggests %>%
+      pkgs.suggests = pkgs.suggests %>%
         str_remove_all("\\s") %>%
         str_split(",", simplify=TRUE) %>%
         as.character()
@@ -226,10 +226,10 @@ pkg_install_suggested=function(by) {
       return(invisible())
     }
   } else {
-    pkgs.suggests=pacman::p_depends(by, character.only=TRUE, local=TRUE)$Suggests
+    pkgs.suggests = pacman::p_depends(by, character.only=TRUE, local=TRUE)$Suggests
   }
-  pkgs.installed=pacman::p_library()
-  pkgs.need.install=base::setdiff(pkgs.suggests, pkgs.installed)
+  pkgs.installed = pacman::p_library()
+  pkgs.need.install = base::setdiff(pkgs.suggests, pkgs.installed)
   if(length(pkgs.need.install)>0) {
     utils::install.packages(pkgs.need.install)
   } else {
@@ -271,19 +271,19 @@ pkg_install_suggested=function(by) {
 #' @return Formatted text.
 #'
 #' @examples
-#' name="Bruce"
+#' name = "Bruce"
 #' Print("My name is <<underline <<bold {name}>>>>.
 #'        <<bold <<blue Pi = {pi:.15}.>>>>
 #'        <<italic <<green 1 + 1 = {1 + 1}.>>>>
 #'        sqrt({x}) = <<red {sqrt(x):.3}>>", x=10)
 #'
 #' @export
-Print=function(...) {
+Print = function(...) {
   tryCatch({
-    output=glue::glue(..., .transformer=sprintf_transformer, .envir=parent.frame())
-    output_color=glue::glue_col( gsub("<<", "{", gsub(">>", "}", output)) )
+    output = glue::glue(..., .transformer=sprintf_transformer, .envir=parent.frame())
+    output_color = glue::glue_col( gsub("<<", "{", gsub(">>", "}", output)) )
     print(output_color)
-  }, error=function(e) {
+  }, error = function(e) {
     warning(e)
     print(...)
   })
@@ -293,20 +293,20 @@ Print=function(...) {
 #' @describeIn Print Paste strings.
 #'
 #' @export
-Glue=function(...) {
-  output=glue::glue(..., .transformer=sprintf_transformer, .envir=parent.frame())
-  output_color=glue::glue_col( gsub("<<", "{", gsub(">>", "}", output)) )
+Glue = function(...) {
+  output = glue::glue(..., .transformer=sprintf_transformer, .envir=parent.frame())
+  output_color = glue::glue_col( gsub("<<", "{", gsub(">>", "}", output)) )
   return(output_color)
 }
 
 
-sprintf_transformer=function(text, envir) {
-  text=glue::glue(text, .envir=envir)
-  m=regexpr(":.+$", text)
+sprintf_transformer = function(text, envir) {
+  text = glue::glue(text, .envir=envir)
+  m = regexpr(":.+$", text)
   if(m!=-1) {
-    format=substring(regmatches(text, m), 2)
-    regmatches(text, m)=""
-    res=eval(parse(text=text, keep.source=FALSE), envir)
+    format = substring(regmatches(text, m), 2)
+    regmatches(text, m) = ""
+    res = eval(parse(text=text, keep.source=FALSE), envir)
     do.call(sprintf, list(glue("%{format}f"), res))
   } else {
     eval(parse(text=text, keep.source=FALSE), envir)
@@ -327,8 +327,8 @@ sprintf_transformer=function(text, envir) {
 #' Run("print({a+b})")
 #'
 #' @export
-Run=function(..., silent=FALSE) {
-  text=glue::glue(..., .sep="\n", .envir=parent.frame())
+Run = function(..., silent=FALSE) {
+  text = glue::glue(..., .sep="\n", .envir=parent.frame())
   if(silent) {
     suppressWarnings({
       eval(parse(text=text), envir=parent.frame())
@@ -342,9 +342,10 @@ Run=function(..., silent=FALSE) {
 
 #' Split up a string (with separators) into a character vector.
 #'
-#' Split up a string (with separators) into a character vector (whitespace around separator is trimmed).
+#' Split up a string (with separators) into a character vector
+#' (whitespace around separator is trimmed).
 #'
-#' @param x Character string.
+#' @param ... Character string(s).
 #' @param sep Pattern for separation.
 #'
 #' Default is \code{"auto"}, including 5 common separators: , ; | \\n \\t.
@@ -360,6 +361,10 @@ Run=function(..., silent=FALSE) {
 #'
 #' cc("A 1 , B 2 ; C 3 | D 4 \t E 5")
 #'
+#' cc("A, B, C",
+#'    " D | E ",
+#'    c("F", "G"))
+#'
 #' cc("
 #' American
 #' British
@@ -367,17 +372,32 @@ Run=function(..., silent=FALSE) {
 #' ")
 #'
 #' @export
-cc=function(x, sep="auto") {
+cc = function(..., sep="auto") {
+  dots = list(...)
+  x = paste(sapply(dots, function(i) paste(i, collapse=",")), collapse=",")
   as.character(
-    stringr::str_trim(
-      stringr::str_split(stringr::str_trim(x),
-                         ifelse(sep=="auto", ",|;|\\||\\n|\\t", sep),
-                         simplify=TRUE)
-    )
+    stringr::str_split(
+      stringr::str_trim(x),
+      ifelse(sep=="auto", "\\s*[,;\\|\\n\\t]\\s*", sep),
+      simplify=TRUE)
   )
 }
 
 
+cc_ci = function(llci, ulci, nsmall) {
+  paste0("[",
+         formatF(llci, nsmall), ", ",
+         formatF(ulci, nsmall), "]")
+}
+
+
+cc_m_ci = function(mean, llci, ulci, nsmall) {
+  paste0(formatF(mean, nsmall), "[",
+         formatF(llci, nsmall), ", ",
+         formatF(ulci, nsmall), "]")
+}
+
+
 #' Repeat a character string for many times and paste them up.
 #'
 #' @param char Character string.
@@ -389,15 +409,15 @@ cc=function(x, sep="auto") {
 #' rep_char("a", 5)
 #'
 #' @export
-rep_char=function(char, rep.times) {
+rep_char = function(char, rep.times) {
   paste(rep(char, times=rep.times), collapse="")
 }
 
 
 ## Capitalize the first letter of a string.
-capitalize=function(string) {
-  capped=grep("^[A-Z]", string, invert = TRUE)
-  substr(string[capped], 1, 1)=toupper(substr(string[capped], 1, 1))
+capitalize = function(string) {
+  capped = grep("^[A-Z]", string, invert=TRUE)
+  substr(string[capped], 1, 1) = toupper(substr(string[capped], 1, 1))
   return(string)
 }
 
@@ -451,85 +471,85 @@ capitalize=function(string) {
 #' print_table(airquality, file="airquality.doc")
 #' unlink("airquality.doc")  # delete file for code check
 #'
-#' model=lm(Temp ~ Month + Day + Wind + Solar.R, data=airquality)
+#' model = lm(Temp ~ Month + Day + Wind + Solar.R, data=airquality)
 #' print_table(model)
 #' print_table(model, file="model.doc")
 #' unlink("model.doc")  # delete file for code check
 #'
 #' @export
-print_table=function(x, digits=3, nsmalls=digits,
-                     nspaces=1,
-                     row.names=TRUE,
-                     col.names=TRUE,
-                     title="", note="", append="",
-                     line=TRUE,
-                     file=NULL,
-                     file.align.head="auto",
-                     file.align.text="auto") {
+print_table = function(x, digits=3, nsmalls=digits,
+                       nspaces=1,
+                       row.names=TRUE,
+                       col.names=TRUE,
+                       title="", note="", append="",
+                       line=TRUE,
+                       file=NULL,
+                       file.align.head="auto",
+                       file.align.text="auto") {
   ## Preprocess data.frame ##
   if(!inherits(x, c("matrix", "data.frame", "data.table"))) {
-    coef.table=coef(summary(x))
-    if(!is.null(coef.table)) x=coef.table
+    coef.table = coef(summary(x))
+    if(!is.null(coef.table)) x = coef.table
   }
-  x=as.data.frame(x)
-  sig=NULL
-  if(length(nsmalls)==1) nsmalls=rep(nsmalls, length(x))
+  x = as.data.frame(x)
+  sig = NULL
+  if(length(nsmalls)==1) nsmalls = rep(nsmalls, length(x))
   for(j in 1:length(x)) {
     if(inherits(x[,j], "factor"))
-      x[,j]=as.character(x[,j])
+      x[,j] = as.character(x[,j])
     if(grepl("Pr\\(|pval|p.value|<i>p</i>", names(x)[j])) {
-      sig=formatF(sig.trans(x[,j]), 0)  # formatF will make * left-aligned
+      sig = formatF(sig.trans(x[,j]), 0)  # formatF will make * left-aligned
       if(grepl("<i>p</i>", names(x)[j])==FALSE)
-        names(x)[j]="p"
-      x[,j]=p.trans(x[,j])
+        names(x)[j] = "p"
+      x[,j] = p.trans(x[,j])
     } else {
-      x[,j]=formatF(x[,j], nsmalls[j])
+      x[,j] = formatF(x[,j], nsmalls[j])
     }
     if(grepl("^S\\.E\\.$|^Std\\. Error$|^se$|^SE$|^BootSE$", names(x)[j])) {
-      x[,j]=paste0("(", x[,j], ")")  # add ( ) to S.E.
-      x[grepl("\\d", x[,j])==FALSE, j]=""  # remove ( ) from blank S.E.
-      if(grepl("S\\.E\\.", names(x)[j])==FALSE) names(x)[j]="S.E."
+      x[,j] = paste0("(", x[,j], ")")  # add ( ) to S.E.
+      x[grepl("\\d", x[,j])==FALSE, j] = ""  # remove ( ) from blank S.E.
+      if(grepl("S\\.E\\.", names(x)[j])==FALSE) names(x)[j] = "S.E."
     }
     if(grepl("^S\\.D\\.$|^Std\\. Deviation$", names(x)[j])) {
-      x[,j]=paste0("(", x[,j], ")")  # add ( ) to S.D.
-      x[grepl("\\d", x[,j])==FALSE, j]=""  # remove ( ) from blank S.E.
-      if(grepl("S\\.D\\.", names(x)[j])==FALSE) names(x)[j]="S.D."
+      x[,j] = paste0("(", x[,j], ")")  # add ( ) to S.D.
+      x[grepl("\\d", x[,j])==FALSE, j] = ""  # remove ( ) from blank S.E.
+      if(grepl("S\\.D\\.", names(x)[j])==FALSE) names(x)[j] = "S.D."
     }
-    # if(grepl("\\[", names(x)[j])) x[,j]=paste0("[", x[,j], ",")
-    # if(grepl("\\]", names(x)[j])) x[,j]=paste0(x[,j], "]")
-    # if(grepl("^[Ee]stimate$", names(x)[j])) names(x)[j]="Coef."
-    names(x)[j]=gsub(" value$|val$", "", names(x)[j])
+    # if(grepl("\\[", names(x)[j])) x[,j] = paste0("[", x[,j], ",")
+    # if(grepl("\\]", names(x)[j])) x[,j] = paste0(x[,j], "]")
+    # if(grepl("^[Ee]stimate$", names(x)[j])) names(x)[j] = "Coef."
+    names(x)[j] = gsub(" value$|val$", "", names(x)[j])
   }
   if(is.null(sig)==FALSE & "sig" %notin% names(x)) {
-    p.pos=which(names(x) %in% c("p", "<i>p</i>"))
-    nvars=length(names(x))
+    p.pos = which(names(x) %in% c("p", "<i>p</i>"))
+    nvars = length(names(x))
     if(p.pos<nvars)
-      x=cbind(x[1:p.pos], ` `=sig, x[(p.pos+1):nvars])
+      x = cbind(x[1:p.pos], ` ` = sig, x[(p.pos+1):nvars])
     else
-      x=cbind(x, ` `=sig)
-    x$` `=as.character(x$` `)
+      x = cbind(x, ` ` = sig)
+    x$` ` = as.character(x$` `)
   }
 
   if(inherits(row.names, "character")) {
-    row.names(x)=row.names
-    row.names=TRUE
+    row.names(x) = row.names
+    row.names = TRUE
   }
   if(inherits(col.names, "character")) {
-    names(x)=col.names
-    col.names=TRUE
+    names(x) = col.names
+    col.names = TRUE
   }
 
   ## Compute length to generate line-chars ##
-  linechar=ifelse(line, "\u2500", "-")
-  title.length=nchar(names(x), type="width")
-  vars.length=c()  # bug: vars.length=apply(apply(x, 2, nchar), 2, max)
-  for(j in 1:length(x)) vars.length[j]=max(nchar(x[,j], type="width"))
-  n.lines=apply(rbind(title.length, vars.length), 2, max)+nspaces
-  n.lines.rn=max(nchar(row.names(x), type="width"))+nspaces
+  linechar = ifelse(line, "\u2500", "-")
+  title.length = nchar(names(x), type="width")
+  vars.length = c()  # bug: vars.length = apply(apply(x, 2, nchar), 2, max)
+  for(j in 1:length(x)) vars.length[j] = max(nchar(x[,j], type="width"))
+  n.lines = apply(rbind(title.length, vars.length), 2, max)+nspaces
+  n.lines.rn = max(nchar(row.names(x), type="width"))+nspaces
   if(row.names)
-    table.line=rep_char(linechar, sum(n.lines)+n.lines.rn)
+    table.line = rep_char(linechar, sum(n.lines)+n.lines.rn)
   else
-    table.line=rep_char(linechar, sum(n.lines))
+    table.line = rep_char(linechar, sum(n.lines))
 
   ## Output ##
   if(is.null(file)) {
@@ -538,19 +558,19 @@ print_table=function(x, digits=3, nsmalls=digits,
     if(row.names)
       cat(rep_char(" ", n.lines.rn))
     for(j in 1:length(x)) {
-      name.j=names(x)[j]
+      name.j = names(x)[j]
       cat(rep_char(" ", n.lines[j]-nchar(name.j, type="width")) %^% name.j)
     }
     cat("\n")
     Print(table.line)
     for(i in 1:nrow(x)) {
       if(row.names) {
-        row.name.i=row.names(x)[i]
+        row.name.i = row.names(x)[i]
         cat(row.name.i %^% rep_char(" ", n.lines.rn-nchar(row.name.i, type="width")))
       }
       for(j in 1:length(x)) {
         # cat(sprintf(glue("% {n.lines[j]}s"), ifelse(is.na(xr[i,j]) | grepl("NA$", xr[i,j]), "", xr[i,j])))
-        x.ij=ifelse(is.na(x[i,j]) | grepl("NA$", x[i,j]), "", x[i,j])
+        x.ij = ifelse(is.na(x[i,j]) | grepl("NA$", x[i,j]), "", x[i,j])
         cat(rep_char(" ", n.lines[j]-nchar(x.ij, type="width")) %^% x.ij)
       }
       cat("\n")
@@ -559,76 +579,76 @@ print_table=function(x, digits=3, nsmalls=digits,
     if(note!="") Print(note)
   }
   if(row.names) {
-    x=cbind(rn=row.names(x), x)
-    names(x)[1]=""
+    x = cbind(rn=row.names(x), x)
+    names(x)[1] = ""
   }
   if(!is.null(file)) {
-    html=df_to_html(x, title=title, note=note, append=append,
-                    file=file,
-                    align.head=file.align.head,
-                    align.text=file.align.text)
+    html = df_to_html(x, title=title, note=note, append=append,
+                      file=file,
+                      align.head=file.align.head,
+                      align.text=file.align.text)
   } else {
-    html=NULL
+    html = NULL
   }
 
   invisible(list(df=x, html=html))
 }
 
 
-df_to_html=function(df, title="", note="", append="",
-                    file=NULL,
-                    align.head="auto",
-                    align.text="auto") {
+df_to_html = function(df, title="", note="", append="",
+                      file=NULL,
+                      align.head="auto",
+                      align.text="auto") {
   if(!is.null(file)) {
     if(file=="NOPRINT") {
-      file=NULL
+      file = NULL
     } else {
-      file=str_replace(file, "\\.docx$", ".doc")
+      file = str_replace(file, "\\.docx$", ".doc")
       if(str_detect(file, "\\.doc$")==FALSE)
-        file=paste0(file, ".doc")
+        file = paste0(file, ".doc")
     }
   }
 
-  TITLE=title
-  TNOTE=note
-  APPEND=append
+  TITLE = title
+  TNOTE = note
+  APPEND = append
 
   if(length(align.head)==1) {
     if(align.head=="auto")
-      align.head=c("left", rep("right", times=ncol(df)-1))
+      align.head = c("left", rep("right", times=ncol(df)-1))
     else
-      align.head=rep(align.head, times=ncol(df))
+      align.head = rep(align.head, times=ncol(df))
   }
   if(length(align.text)==1) {
     if(align.text=="auto")
-      align.text=c("left", rep("right", times=ncol(df)-1))
+      align.text = c("left", rep("right", times=ncol(df)-1))
     else
-      align.text=rep(align.text, times=ncol(df))
+      align.text = rep(align.text, times=ncol(df))
   }
 
-  df=as.data.frame(df)
+  df = as.data.frame(df)
   for(j in 1:ncol(df)) {
-    df[[j]]="<td align='" %^% align.text[j] %^% "'>" %^%
+    df[[j]] = "<td align='" %^% align.text[j] %^% "'>" %^%
       str_trim(str_replace_all(df[[j]], "^\\s*-{1}", "\u2013")) %^% "</td>"
   }
 
-  THEAD="<tr> " %^%
+  THEAD = "<tr> " %^%
     paste("<th align='" %^%
             align.head %^%
             "'>" %^% names(df) %^% "</th>",
           collapse=" ") %^% " </tr>"
 
-  TBODY="<tr> " %^%
+  TBODY = "<tr> " %^%
     paste(apply(df, 1, function(...) paste(..., collapse=" ")),
           collapse=" </tr>\n<tr> ") %^% " </tr>"
-  TBODY=TBODY %>%
+  TBODY = TBODY %>%
     str_replace_all(">\\s*NA\\s*<", "><") %>%
     str_replace_all("\\s+</td>", "</td>") %>%
     str_replace_all("\\[\\s+", "[") %>%
     str_replace_all("\\,\\s+", ", ") %>%
     str_replace_all("<\\.001", "< .001")
 
-  TABLE=paste0("
+  TABLE = paste0("
 <table>
 <thead>
 ", THEAD, "
@@ -639,7 +659,7 @@ df_to_html=function(df, title="", note="", append="",
 </table>
 ")
 
-  HTML=paste0("<!DOCTYPE html>
+  HTML = paste0("<!DOCTYPE html>
 <html>
 
 <head>
@@ -670,7 +690,7 @@ table th, table td {padding-left: 5px; padding-right: 5px; height: 19px;}
       # sink(file)
       # cat(HTML)
       # sink()
-      f=file(file, "w", encoding="UTF-8")
+      f = file(file, "w", encoding="UTF-8")
       cat(HTML, file=f)
       close(f)
       Print("<<green \u221a>> Table saved to <<bold \"{paste0(getwd(), '/', file)}\">>")
@@ -695,7 +715,7 @@ table th, table td {padding-left: 5px; padding-right: 5px; height: 19px;}
 #' @seealso \code{\link[base:format]{format}}, \code{\link{formatF}}
 #'
 #' @export
-formatN=function(x, mark=",") {
+formatN = function(x, mark=",") {
   format(x, big.mark=mark)
 }
 
@@ -713,13 +733,13 @@ formatN=function(x, mark=",") {
 #' @seealso \code{\link[base:format]{format}}, \code{\link{formatN}}
 #'
 #' @export
-formatF=function(x, digits=3, nsmall=digits) {
+formatF = function(x, digits=3, nsmall=digits) {
   # format(x, digits=0, nsmall=nsmall, scientific=FALSE)
   if(inherits(x, "character")) {
-    xf=sprintf(paste0("%-", max(nchar(x), na.rm=TRUE), "s"), x)  # left adjustment
+    xf = sprintf(paste0("%-", max(nchar(x), na.rm=TRUE), "s"), x)  # left adjustment
   } else {
-    x=sprintf(paste0("%.", nsmall, "f"), x)
-    xf=sprintf(paste0("%", max(nchar(x), na.rm=TRUE), "s"), x)
+    x = sprintf(paste0("%.", nsmall, "f"), x)
+    xf = sprintf(paste0("%", max(nchar(x), na.rm=TRUE), "s"), x)
   }
   return(xf)
 }
@@ -738,7 +758,7 @@ formatF=function(x, digits=3, nsmall=digits) {
 #' RGB(255, 0, 0, 0.8)  # red with 80\% opacity: "#FF0000CC"
 #'
 #' @export
-RGB=function(r, g, b, alpha) {
+RGB = function(r, g, b, alpha) {
   grDevices::rgb(r/255, g/255, b/255, alpha)
 }
 
@@ -752,12 +772,15 @@ RGB=function(r, g, b, alpha) {
 #' @return A character string of time difference.
 #'
 #' @examples
-#' t0=Sys.time()
+#' \dontrun{
+#'
+#' t0 = Sys.time()
 #' dtime(t0)
+#' }
 #'
 #' @export
-dtime=function(t0, unit="secs", digits=0, nsmall=digits) {
-  dt=difftime(Sys.time(), t0, units=unit)
+dtime = function(t0, unit="secs", digits=0, nsmall=digits) {
+  dt = difftime(Sys.time(), t0, units=unit)
   format(dt, digits=1, nsmall=nsmall)
 }
 
@@ -797,31 +820,31 @@ dtime=function(t0, unit="secs", digits=0, nsmall=digits) {
 #' @describeIn set.wd Main function
 #' @aliases set_wd
 #' @export
-set.wd=function(path=NULL, ask=FALSE) {
+set.wd = function(path=NULL, ask=FALSE) {
   # if(rstudioapi::isAvailable()==FALSE)
   #   stop("[RStudio] is required for running this function!\n",
   #        "Please download and install the latest version of RStudio:\n",
   #        "https://www.rstudio.com/products/rstudio/download/", call.=TRUE)
-  is.windows=ifelse(Sys.info()[["sysname"]]=="Windows", TRUE, FALSE)
+  is.windows = ifelse(Sys.info()[["sysname"]]=="Windows", TRUE, FALSE)
   if(is.null(path)) {
     tryCatch({
       if(ask) {
         # RStudio version >= 1.1.287
         if(is.windows)
-          path=iconv(rstudioapi::selectDirectory(), from="UTF-8", to="GBK")
+          path = iconv(rstudioapi::selectDirectory(), from="UTF-8", to="GBK")
         else
-          path=rstudioapi::selectDirectory()
+          path = rstudioapi::selectDirectory()
       } else {
         # # RStudio version >= 1.4.843
         # if(is.windows)
-        #   file.path=iconv(rstudioapi::documentPath(), from="UTF-8", to="GBK")
+        #   file.path = iconv(rstudioapi::documentPath(), from="UTF-8", to="GBK")
         # else
-        #   file.path=rstudioapi::documentPath()
+        #   file.path = rstudioapi::documentPath()
 
         # RStudio version >= 0.99.1111
-        path=dirname(rstudioapi::getSourceEditorContext()$path)
+        path = dirname(rstudioapi::getSourceEditorContext()$path)
       }
-    }, error=function(e) {
+    }, error = function(e) {
       # Error: Function documentPath not found in RStudio
       message("Your RStudio version is: ", rstudioapi::getVersion(), "\n")
       message("Please update RStudio to the latest version:\n",
@@ -839,12 +862,12 @@ set.wd=function(path=NULL, ask=FALSE) {
 
 #' @describeIn set.wd The alias of \code{set.wd} (the same)
 #' @export
-set_wd=set.wd
+set_wd = set.wd
 
 
-file_ext=function(filename) {
-  filename=str_trim(filename)
-  pos=regexpr("\\.([[:alnum:]]+)$", filename)
+file_ext = function(filename) {
+  filename = str_trim(filename)
+  pos = regexpr("\\.([[:alnum:]]+)$", filename)
   ifelse(pos>-1L, tolower(substring(filename, pos+1L)), "")
 }
 
@@ -902,89 +925,89 @@ file_ext=function(filename) {
 #' \dontrun{
 #'
 #'   # Import data from system clipboard
-#'   data=import()  # read from clipboard (on Windows and Mac OS)
+#'   data = import()  # read from clipboard (on Windows and Mac OS)
 #'
 #'   # If you have an Excel file named "mydata.xlsx"
 #'   export(airquality, file="mydata.xlsx")
 #'
 #'   # Import data from a file
-#'   data=import("mydata.xlsx")  # default: data.frame
-#'   data=import("mydata.xlsx", as="data.table")
+#'   data = import("mydata.xlsx")  # default: data.frame
+#'   data = import("mydata.xlsx", as="data.table")
 #' }
 #'
 #' @seealso \code{\link{export}}
 #'
 #' @export
-import=function(file,
-                sheet=NULL, range=NULL,
-                encoding=NULL, header="auto",
-                setclass=as, as="data.frame") {
+import = function(file,
+                  sheet=NULL, range=NULL,
+                  encoding=NULL, header="auto",
+                  setclass=as, as="data.frame") {
   ## initialize
   if(missing(file)) {
-    file="clipboard"
-    fmt="clipboard"
+    file = "clipboard"
+    fmt = "clipboard"
   } else {
     if(file.exists(file)==FALSE)
       stop("No such file. Did you forget adding the path or file extension?", call.=FALSE)
-    fmt=file_ext(file)  # file format extracted from file extension
+    fmt = file_ext(file)  # file format extracted from file extension
   }
 
   ## import data
   if(fmt=="") {
     stop("File has no extension.", call.=FALSE)
   } else if(fmt=="clipboard") {
-    if(header=="auto") header=TRUE
-    x=clipr::read_clip()
+    if(header=="auto") header = TRUE
+    x = clipr::read_clip()
     if(is.null(x) | (is.character(x) & length(x)==1 & x[1]==""))
       stop("The system clipboard is empty. You may first copy something.", call.=FALSE)
     else
-      data=clipr::read_clip_tbl(x=x, header=header)
+      data = clipr::read_clip_tbl(x=x, header=header)
   } else if(fmt %in% c("rds")) {
-    data=readRDS(file=file)
+    data = readRDS(file=file)
   } else if(fmt %in% c("rda", "rdata")) {
-    envir=new.env()
+    envir = new.env()
     load(file=file, envir=envir)
     if(length(ls(envir))>1)
-      warning("Rdata file contains multiple objects. Returning the first object.", call.=TRUE)
-    data=get(ls(envir)[1], envir)
+      warning("RData file contains multiple objects. Returning the first object.", call.=FALSE)
+    data = get(ls(envir)[1], envir)
   } else if(fmt %in% c("txt", "csv", "csv2", "tsv", "psv")) {
-    if(is.null(encoding)) encoding="unknown"
-    data=data.table::fread(input=file,
-                           sep="auto",
-                           encoding=encoding,
-                           header=header)
+    if(is.null(encoding)) encoding = "unknown"
+    data = data.table::fread(input=file,
+                             sep="auto",
+                             encoding=encoding,
+                             header=header)
   } else if(fmt %in% c("xls", "xlsx")) {
-    if(header=="auto") header=TRUE
-    data=readxl::read_excel(path=file,
-                            sheet=sheet,
-                            range=range,
-                            col_names=header)
+    if(header=="auto") header = TRUE
+    data = readxl::read_excel(path=file,
+                              sheet=sheet,
+                              range=range,
+                              col_names=header)
   } else if(fmt %in% c("sav")) {
     try({
-      error=TRUE
-      data=foreign::read.spss(
+      error = TRUE
+      data = foreign::read.spss(
         file=file,
         reencode=ifelse(is.null(encoding), NA, encoding),
         to.data.frame=TRUE,
         use.value.labels=FALSE)
-      error=FALSE
+      error = FALSE
     }, silent=TRUE)
     if(error) {
       message("[Retry] Using `haven::read_sav()` to import the data...")
-      data=haven::read_sav(file=file, encoding=encoding)
+      data = haven::read_sav(file=file, encoding=encoding)
     }
   } else if(fmt %in% c("dta")) {
     try({
-      error=TRUE
-      data=foreign::read.dta(file=file, convert.factors=FALSE)
-      error=FALSE
+      error = TRUE
+      data = foreign::read.dta(file=file, convert.factors=FALSE)
+      error = FALSE
     }, silent=TRUE)
     if(error) {
       message("[Retry] Using `haven::read_dta()` to import the data...")
-      data=haven::read_dta(file=file, encoding=encoding)
+      data = haven::read_dta(file=file, encoding=encoding)
     }
   } else {
-    data=rio::import(file=file)
+    data = rio::import(file=file)
   }
 
   ## report data
@@ -1064,28 +1087,28 @@ import=function(file,
 #'   export(list(airquality, npk), sheet=c("air", "npk"), file="mydata.xlsx")
 #'
 #'   export(list(a=1, b=npk, c="character"), file="abc.Rdata")  # .rda, .rdata
-#'   d=import("abc.Rdata")  # load only the first object and rename it to `d`
+#'   d = import("abc.Rdata")  # load only the first object and rename it to `d`
 #'   load("abc.Rdata")  # load all objects with original names to environment
 #'
 #'   export(lm(yield ~ N*P*K, data=npk), file="lm_npk.Rdata")
-#'   model=import("lm_npk.Rdata")
+#'   model = import("lm_npk.Rdata")
 #'   load("lm_npk.Rdata")  # because x is unnamed, the object has a name "List1"
 #'
 #'   export(list(m1=lm(yield ~ N*P*K, data=npk)), file="lm_npk.Rdata")
-#'   model=import("lm_npk.Rdata")
+#'   model = import("lm_npk.Rdata")
 #'   load("lm_npk.Rdata")  # because x is named, the object has a name "m1"
 #' }
 #'
 #' @seealso \code{\link{import}}, \code{\link{print_table}}
 #'
 #' @export
-export=function(x, file, sheet=NULL,
-                encoding=NULL, header="auto",
-                overwrite=TRUE) {
+export = function(x, file, sheet=NULL,
+                  encoding=NULL, header="auto",
+                  overwrite=TRUE) {
   ## initialize
   if(missing(file)) {
-    file="clipboard"
-    fmt="clipboard"
+    file = "clipboard"
+    fmt = "clipboard"
   } else {
     if(file.exists(file)==TRUE) {
       if(overwrite)
@@ -1093,14 +1116,14 @@ export=function(x, file, sheet=NULL,
       else
         stop("File \"", file, "\" existed!", call.=FALSE)
     }
-    fmt=file_ext(file)  # file format extracted from file extension
+    fmt = file_ext(file)  # file format extracted from file extension
   }
 
   ## export data
   if(fmt=="") {
     stop("File has no extension.", call.=FALSE)
   } else if(fmt=="clipboard") {
-    if(header=="auto") header=TRUE
+    if(header=="auto") header = TRUE
     suppressWarnings({
       clipr::write_clip(content=x, sep="\t",
                         row.names=FALSE,
@@ -1112,10 +1135,10 @@ export=function(x, file, sheet=NULL,
     if(is.data.frame(x)) {
       save(x, file=file)
     } else if(is.list(x)) {
-      if(inherits(x, "list")==FALSE) x=list(x)
+      if(inherits(x, "list")==FALSE) x = list(x)
       if(is.null(names(x)))
-        names(x)=paste0("List", 1:length(x))
-      envir=as.environment(x)
+        names(x) = paste0("List", 1:length(x))
+      envir = as.environment(x)
       save(list=names(x), file=file, envir=envir)
     } else if(is.environment(x)) {
       save(list=ls(x), file=file, envir=x)
@@ -1125,14 +1148,14 @@ export=function(x, file, sheet=NULL,
       stop("`x` must be a data.frame, list, or environment.", call.=FALSE)
     }
   } else if(fmt %in% c("txt", "csv", "csv2", "tsv", "psv")) {
-    sep=switch(fmt,
-               txt="\t",
-               csv=",",
-               csv2=";",
-               tsv="\t",
-               psv="|")
-    dec=ifelse(fmt=="csv2", ",", ".")
-    if(header=="auto") header=TRUE
+    sep = switch(fmt,
+                 txt="\t",
+                 csv=",",
+                 csv2=";",
+                 tsv="\t",
+                 psv="|")
+    dec = ifelse(fmt=="csv2", ",", ".")
+    if(header=="auto") header = TRUE
     if(is.null(encoding)) {
       data.table::fwrite(x=x, file=file,
                          sep=sep, dec=dec,
@@ -1147,22 +1170,22 @@ export=function(x, file, sheet=NULL,
                          fileEncoding=encoding)
     }
   } else if(fmt %in% c("xls", "xlsx")) {
-    if(inherits(x, "list")==FALSE) x=list(x)  # one element
-    if(header=="auto") header=TRUE
+    if(inherits(x, "list")==FALSE) x = list(x)  # one element
+    if(header=="auto") header = TRUE
     if(is.null(sheet)) {
       if(is.null(names(x)))
-        names(x)=paste0("Sheet", 1:length(x))
+        names(x) = paste0("Sheet", 1:length(x))
       openxlsx::write.xlsx(x=x, file=file,
                            overwrite=overwrite,
                            rowNames=FALSE,
                            colNames=header)
     } else {
-      sheet=as.character(sheet)
+      sheet = as.character(sheet)
       if(length(x)==length(sheet)) {
-        n=length(x)
+        n = length(x)
         if(file.exists(file)) {
-          wb=openxlsx::loadWorkbook(file=file)
-          sheets=openxlsx::getSheetNames(file=file)
+          wb = openxlsx::loadWorkbook(file=file)
+          sheets = openxlsx::getSheetNames(file=file)
           for(i in 1:n) {
             if(sheet[i] %in% sheets)
               openxlsx::removeWorksheet(wb, sheet=sheet[i])
@@ -1173,7 +1196,7 @@ export=function(x, file, sheet=NULL,
           }
           openxlsx::saveWorkbook(wb, file=file, overwrite=TRUE)
         } else {
-          names(x)=sheet
+          names(x) = sheet
           openxlsx::write.xlsx(x=x, file=file,
                                overwrite=overwrite,
                                rowNames=FALSE,
@@ -1184,10 +1207,10 @@ export=function(x, file, sheet=NULL,
       }
     }
   } else if(fmt %in% c("sav")) {
-    x=restore_labelled(x)
+    x = restore_labelled(x)
     haven::write_sav(data=x, path=file)
   } else if(fmt %in% c("dta")) {
-    x=restore_labelled(x)
+    x = restore_labelled(x)
     haven::write_dta(data=x, path=file)
   } else {
     rio::export(x=x, file=file)
@@ -1201,19 +1224,19 @@ export=function(x, file, sheet=NULL,
 }
 
 
-restore_labelled=function(x) {
+restore_labelled = function(x) {
   # restore labelled variable classes
-  x[]=lapply(x, function(v) {
+  x[] = lapply(x, function(v) {
     if(is.factor(v)) {
       haven::labelled(
-        x=as.numeric(v),
-        labels=stats::setNames(seq_along(levels(v)), levels(v)),
-        label=attr(v, "label", exact=TRUE))
+        x = as.numeric(v),
+        labels = stats::setNames(seq_along(levels(v)), levels(v)),
+        label = attr(v, "label", exact=TRUE))
     } else if(!is.null(attr(v, "labels", exact=TRUE)) | !is.null(attr(v, "label", exact=TRUE))) {
       haven::labelled(
-        x=v,
-        labels=attr(v, "labels", exact=TRUE),
-        label=attr(v, "label", exact=TRUE))
+        x = v,
+        labels = attr(v, "labels", exact=TRUE),
+        label = attr(v, "label", exact=TRUE))
     } else {
       v
     }
@@ -1252,35 +1275,35 @@ restore_labelled=function(x) {
 #' \href{https://www.excel-university.com/xlookup/}{XLOOKUP: Excel University}
 #'
 #' @examples
-#' ref=data.table(City=rep(c("A", "B", "C"), each=5),
-#'                Year=rep(2013:2017, times=3),
-#'                GDP=sample(1000:2000, 15),
-#'                PM2.5=sample(10:300, 15))
+#' ref = data.table(City=rep(c("A", "B", "C"), each=5),
+#'                  Year=rep(2013:2017, times=3),
+#'                  GDP=sample(1000:2000, 15),
+#'                  PM2.5=sample(10:300, 15))
 #' ref
 #'
-#' data=data.table(sub=1:5,
-#'                 city=c("A", "A", "B", "C", "C"),
-#'                 year=c(2013, 2014, 2015, 2016, 2017))
+#' data = data.table(sub=1:5,
+#'                   city=c("A", "A", "B", "C", "C"),
+#'                   year=c(2013, 2014, 2015, 2016, 2017))
 #' data
 #'
 #' LOOKUP(data, c("city", "year"), ref, c("City", "Year"), "GDP")
 #' LOOKUP(data, c("city", "year"), ref, c("City", "Year"), c("GDP", "PM2.5"))
 #'
 #' @export
-LOOKUP=function(data, vars,
-                data.ref, vars.ref,
-                vars.lookup,
-                return=c("new.data", "new.var", "new.value")) {
-  by=vars.ref
-  names(by)=vars
-  data.ref=as.data.frame(data.ref)
-  data.new=left_join(data,
-                     data.ref[c(vars.ref, vars.lookup)],
-                     by=by)
-  if(nrow(data.new)>nrow(data))
+LOOKUP = function(data, vars,
+                  data.ref, vars.ref,
+                  vars.lookup,
+                  return=c("new.data", "new.var", "new.value")) {
+  by = vars.ref
+  names(by) = vars
+  data.ref = as.data.frame(data.ref)
+  data.new = left_join(data,
+                       data.ref[c(vars.ref, vars.lookup)],
+                       by=by)
+  if(nrow(data.new) > nrow(data))
     warning("More than one values are matched!", call.=TRUE)
-  if(length(return)==3) return="new.data"
-  if(return=="new.value" & length(vars.lookup)>=2) return="new.var"
+  if(length(return)==3) return = "new.data"
+  if(return=="new.value" & length(vars.lookup)>=2) return = "new.var"
   if(return=="new.data") {
     return(data.new)
   } else if(return=="new.var") {
