@@ -23,45 +23,45 @@
 #' p(chi2=3.84, df=1)
 #'
 #' @export
-p=function(z=NULL, t=NULL, f=NULL, r=NULL, chi2=NULL,
-           n=NULL, df=NULL, df1=NULL, df2=NULL, digits=2, nsmall=digits) {
-  if(!is.null(z)) {p=p.z(z); pstat=Glue("<<italic z>> = {z:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(t)) {p=p.t(t, df); pstat=Glue("<<italic t>>({df}) = {t:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(f)) {p=p.f(f, df1, df2); pstat=Glue("<<italic F>>({df1}, {df2}) = {f:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(r)) {p=p.r(r, n); pstat=Glue("<<italic r>>({n-2}) = {r:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(chi2)) {p=p.chi2(chi2, df); pstat=Glue("\u03c7\u00b2({df}{ifelse(is.null(n), '', ', <<italic N>> = ' %^% n)}) = {chi2:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
+p = function(z=NULL, t=NULL, f=NULL, r=NULL, chi2=NULL,
+             n=NULL, df=NULL, df1=NULL, df2=NULL, digits=2, nsmall=digits) {
+  if(!is.null(z)) {p = p.z(z); pstat = Glue("<<italic z>> = {z:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(t)) {p = p.t(t, df); pstat = Glue("<<italic t>>({df}) = {t:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(f)) {p = p.f(f, df1, df2); pstat = Glue("<<italic F>>({df1}, {df2}) = {f:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(r)) {p = p.r(r, n); pstat = Glue("<<italic r>>({n-2}) = {r:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(chi2)) {p = p.chi2(chi2, df); pstat = Glue("\u03c7\u00b2({df}{ifelse(is.null(n), '', ', <<italic N>> = ' %^% n)}) = {chi2:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
   return(pstat)
 }
 
-p.plain=function(z=NULL, t=NULL, f=NULL, r=NULL, chi2=NULL,
-                 n=NULL, df=NULL, df1=NULL, df2=NULL, digits=2, nsmall=digits) {
-  if(!is.null(z)) {p=p.z(z); pstat=Glue("z = {z:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(t)) {p=p.t(t, df); pstat=Glue("t({df}) = {t:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(f)) {p=p.f(f, df1, df2); pstat=Glue("F({df1}, {df2}) = {f:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(r)) {p=p.r(r, n); pstat=Glue("r({n-2}) = {r:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(chi2)) {p=p.chi2(chi2, df); pstat=Glue("\u03c7\u00b2({df}{ifelse(is.null(n), '', ', N = ' %^% n)}) = {chi2:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
+p.plain = function(z=NULL, t=NULL, f=NULL, r=NULL, chi2=NULL,
+                   n=NULL, df=NULL, df1=NULL, df2=NULL, digits=2, nsmall=digits) {
+  if(!is.null(z)) {p = p.z(z); pstat = Glue("z = {z:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(t)) {p = p.t(t, df); pstat = Glue("t({df}) = {t:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(f)) {p = p.f(f, df1, df2); pstat = Glue("F({df1}, {df2}) = {f:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(r)) {p = p.r(r, n); pstat = Glue("r({n-2}) = {r:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(chi2)) {p = p.chi2(chi2, df); pstat = Glue("\u03c7\u00b2({df}{ifelse(is.null(n), '', ', N = ' %^% n)}) = {chi2:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
   return(pstat)
 }
 
 #' @describeIn p Two-tailed \emph{p} value of \emph{z}.
 #' @export
-p.z=function(z) pnorm(abs(z), lower.tail=FALSE)*2
+p.z = function(z) pnorm(abs(z), lower.tail=FALSE)*2
 
 #' @describeIn p Two-tailed \emph{p} value of \emph{t}.
 #' @export
-p.t=function(t, df) pt(abs(t), df, lower.tail=FALSE)*2
+p.t = function(t, df) pt(abs(t), df, lower.tail=FALSE)*2
 
 #' @describeIn p One-tailed \emph{p} value of \emph{F}. (Note: \emph{F} test is one-tailed only.)
 #' @export
-p.f=function(f, df1, df2) pf(f, df1, df2, lower.tail=FALSE)
+p.f = function(f, df1, df2) pf(f, df1, df2, lower.tail=FALSE)
 
 #' @describeIn p Two-tailed \emph{p} value of \emph{r}.
 #' @export
-p.r=function(r, n) p.t(r/sqrt((1-r^2)/(n-2)), n-2)
+p.r = function(r, n) p.t(r/sqrt((1-r^2)/(n-2)), n-2)
 
 #' @describeIn p One-tailed \emph{p} value of \eqn{\chi}^2. (Note: \eqn{\chi}^2 test is one-tailed only.)
 #' @export
-p.chi2=function(chi2, df) ifelse(df==0, 1, pchisq(chi2, df, lower.tail=FALSE))
+p.chi2 = function(chi2, df) ifelse(df==0, 1, pchisq(chi2, df, lower.tail=FALSE))
 
 
 ## Transform \emph{p} value.
@@ -77,7 +77,7 @@ p.chi2=function(chi2, df) ifelse(df==0, 1, pchisq(chi2, df, lower.tail=FALSE))
 ## @seealso \code{\link{p.trans2}}
 ##
 ## @export
-p.trans=function(p, nsmall.p=3) {
+p.trans = function(p, nsmall.p=3) {
   mapply(function(p, nsmall.p) {
     ifelse(is.na(p) | p > 1 | p < 0, "",
            ifelse(p < 10^-nsmall.p, gsub("0(?=\\.)", "", Glue("<{10^-nsmall.p:.{nsmall.p}}"), perl=T),
@@ -99,7 +99,7 @@ p.trans=function(p, nsmall.p=3) {
 ## @seealso \code{\link{p.trans}}
 ##
 ## @export
-p.trans2=function(p, nsmall.p=3, p.min=1e-99) {
+p.trans2 = function(p, nsmall.p=3, p.min=1e-99) {
   ifelse(is.na(p) | p > 1 | p < 0, "",
          ifelse(p < p.min, paste("<", p.min),
                 ifelse(p < 10^-nsmall.p, paste("=", format(p, digits=1, scientific=TRUE)),
@@ -117,7 +117,7 @@ p.trans2=function(p, nsmall.p=3, p.min=1e-99) {
 ## sig.trans(c(1, 0.09, 0.049, 0.009, 0.001, 0.0001, 1e-50)) %>% data.table(sig=.)
 ##
 ## @export
-sig.trans=function(p) {
+sig.trans = function(p) {
   ifelse(is.na(p) | p > 1 | p < 0, "",
          ifelse(p < .001, "***",
                 ifelse(p < .01, "** ",
@@ -162,15 +162,15 @@ sig.trans=function(p) {
 #' # ?psych::bfi
 #' Describe(psych::bfi[c("age", "gender", "education")])
 #'
-#' d=as.data.table(psych::bfi)
+#' d = as.data.table(psych::bfi)
 #' d[, `:=`(
-#'   gender=as.factor(gender),
-#'   education=as.factor(education),
-#'   E=MEAN(d, "E", 1:5, rev=c(1,2), likert=1:6),
-#'   A=MEAN(d, "A", 1:5, rev=1, likert=1:6),
-#'   C=MEAN(d, "C", 1:5, rev=c(4,5), likert=1:6),
-#'   N=MEAN(d, "N", 1:5, likert=1:6),
-#'   O=MEAN(d, "O", 1:5, rev=c(2,5), likert=1:6)
+#'   gender = as.factor(gender),
+#'   education = as.factor(education),
+#'   E = MEAN(d, "E", 1:5, rev=c(1,2), likert=1:6),
+#'   A = MEAN(d, "A", 1:5, rev=1, likert=1:6),
+#'   C = MEAN(d, "C", 1:5, rev=c(4,5), likert=1:6),
+#'   N = MEAN(d, "N", 1:5, likert=1:6),
+#'   O = MEAN(d, "O", 1:5, rev=c(2,5), likert=1:6)
 #' )]
 #' Describe(d[, .(age, gender, education)], plot=TRUE, all.as.numeric=FALSE)
 #' Describe(d[, .(age, gender, education, E, A, C, N, O)], plot=TRUE)
@@ -178,64 +178,64 @@ sig.trans=function(p) {
 #' @seealso \code{\link{Corr}}
 #'
 #' @export
-Describe=function(data,
-                  all.as.numeric=TRUE,
-                  digits=2, nsmall=digits,
-                  file=NULL,
-                  plot=FALSE,
-                  upper.triangle=FALSE, upper.smooth="none",
-                  plot.file=NULL, plot.width=8, plot.height=6, plot.dpi=500) {
-  if(is.numeric(data)) data=data.frame(X=data)
-  desc=as.data.frame(psych::describe(data, fast=FALSE))
+Describe = function(data,
+                    all.as.numeric=TRUE,
+                    digits=2, nsmall=digits,
+                    file=NULL,
+                    plot=FALSE,
+                    upper.triangle=FALSE, upper.smooth="none",
+                    plot.file=NULL, plot.width=8, plot.height=6, plot.dpi=500) {
+  if(is.numeric(data)) data = data.frame(X=data)
+  desc = as.data.frame(psych::describe(data, fast=FALSE))
   desc$vars = desc$trimmed = desc$mad = desc$range = desc$se = NULL
-  names(desc)=c("N", "Mean", "SD", "Median", "Min", "Max", "Skewness", "Kurtosis")
-  desc$`|`="|"
-  desc$Missing=NA
-  desc=desc[c("N", "Missing", "Mean", "SD", "|",
-              "Median", "Min", "Max", "Skewness", "Kurtosis")]
+  names(desc) = c("N", "Mean", "SD", "Median", "Min", "Max", "Skewness", "Kurtosis")
+  desc$`|` = "|"
+  desc$Missing = NA
+  desc = desc[c("N", "Missing", "Mean", "SD", "|",
+                "Median", "Min", "Max", "Skewness", "Kurtosis")]
 
   if(length(as.data.frame(data))==1)
-    row.names(desc)=" "  # as.character(sys.call())[2]
-  missing=nrow(data)-desc$N
+    row.names(desc) = " "  # as.character(sys.call())[2]
+  missing = nrow(data) - desc$N
   if(max(missing)==0) {
-    desc$Missing=NULL
-    nsmalls=c(0, rep(nsmall, 8))
+    desc$Missing = NULL
+    nsmalls = c(0, rep(nsmall, 8))
   } else {
-    desc$Missing=ifelse(missing==0, NA, missing)
-    names(desc)[2]="(NA)"
-    nsmalls=c(0, 0, rep(nsmall, 8))
+    desc$Missing = ifelse(missing==0, NA, missing)
+    names(desc)[2] = "(NA)"
+    nsmalls = c(0, 0, rep(nsmall, 8))
   }
   print_table(desc, nsmalls=nsmalls, file=file,
               title="Descriptive Statistics:")
 
-  data.new=as.data.frame(data)
-  vars.not.numeric=c()
+  data.new = as.data.frame(data)
+  vars.not.numeric = c()
   if(all.as.numeric) {
     for(var in names(data.new)) {
       if(!is.numeric(data.new[[var]])) {
-        data.new[[var]]=as.numeric(data.new[[var]])
-        vars.not.numeric=c(vars.not.numeric, var)
+        data.new[[var]] = as.numeric(data.new[[var]])
+        vars.not.numeric = c(vars.not.numeric, var)
       }
     }
   }
   if(length(vars.not.numeric)>0)
     Print("\n\n\n<<yellow NOTE: `{paste(vars.not.numeric, collapse='`, `')}` transformed to numeric.>>")
 
-  p=NULL
+  p = NULL
   if(plot) {
     # if(!pacman::p_isinstalled("GGally"))
     #   stop("Package `GGally` needs to be installed for plotting.\nRun this code: install.packages(\"GGally\")", call.=FALSE)
     if(upper.triangle) {
-      smooth=switch(upper.smooth,
-                    "none"="points",
-                    "lm"="smooth",
-                    "loess"="smooth_loess")
-      upper=list(continuous=GGally::wrap(
+      smooth = switch(upper.smooth,
+                      "none"="points",
+                      "lm"="smooth",
+                      "loess"="smooth_loess")
+      upper = list(continuous=GGally::wrap(
         smooth, size=1, shape=16, alpha=0.3))
     } else {
-      upper="blank"
+      upper = "blank"
     }
-    p=GGally::ggpairs(
+    p = GGally::ggpairs(
       data.new, switch="both", axisLabels="none",
       upper=upper,
       lower=list(continuous=GGally::wrap(
@@ -249,8 +249,8 @@ Describe=function(data,
     } else {
       cowplot::ggsave2(plot=p, filename=plot.file,
                        width=plot.width, height=plot.height, dpi=plot.dpi)
-      plot.file=str_split(plot.file, "/", simplify=TRUE)
-      plot.path=paste0(getwd(), '/', plot.file[length(plot.file)])
+      plot.file = str_split(plot.file, "/", simplify=TRUE)
+      plot.path = paste0(getwd(), '/', plot.file[length(plot.file)])
       Print("\n\n\n<<green \u221a>> Plot saved to <<blue '{plot.path}'>>")
     }
   }
@@ -272,7 +272,7 @@ Describe=function(data,
 #' @return A data frame of frequency statistics.
 #'
 #' @examples
-#' data=psych::bfi
+#' data = psych::bfi
 #'
 #' ## Input `data$variable`
 #' Freq(data$education)
@@ -285,40 +285,40 @@ Describe=function(data,
 #' Freq(data, "age")
 #'
 #' @export
-Freq=function(x, varname, labels, sort="",
-              digits=1, nsmall=digits, file=NULL) {
+Freq = function(x, varname, labels, sort="",
+                digits=1, nsmall=digits, file=NULL) {
   if(inherits(x, "data.frame")) {
     if(missing(varname))
       stop("Please also specify `varname` (variable name). See help page: help(Freq)", call.=FALSE)
     if(length(varname)>1)
       stop("Please specify only ONE variable name.", call.=FALSE)
-    var=as.data.frame(x)[[varname]]
+    var = as.data.frame(x)[[varname]]
   } else {
-    var=x
+    var = x
   }
-  table.var=table(var)
-  N.na=sum(is.na(var))
-  N=sum(table.var)+N.na
-  if(missing(labels)) labels=names(table.var)
-  output=cbind(matrix(table.var,
-                      dimnames=list(labels, "N")),
-               matrix(round(table.var/N*100, nsmall),
-                      dimnames=list(labels, "%")))
-  if(N.na) output=rbind(output,
-                        matrix(c(N.na, round(N.na/N*100, nsmall)),
-                               ncol=2, dimnames=list("(NA)")))
+  table.var = table(var)
+  N.na = sum(is.na(var))
+  N = sum(table.var) + N.na
+  if(missing(labels)) labels = names(table.var)
+  output = cbind(matrix(table.var,
+                        dimnames=list(labels, "N")),
+                 matrix(round(table.var/N*100, nsmall),
+                        dimnames=list(labels, "%")))
+  if(N.na) output = rbind(output,
+                          matrix(c(N.na, round(N.na/N*100, nsmall)),
+                                 ncol=2, dimnames=list("(NA)")))
   if(sort=="-")
-    output=output[order(output[,"N"], decreasing=TRUE),]
+    output = output[order(output[,"N"], decreasing=TRUE),]
   if(sort=="+")
-    output=output[order(output[,"N"], decreasing=FALSE),]
+    output = output[order(output[,"N"], decreasing=FALSE),]
 
   if(is.null(file)) {
-    note=Glue("Total <<italic N>> = {formatN(N)}")
-    if(N.na>0) note=note %^% "\n" %^%
+    note = Glue("Total <<italic N>> = {formatN(N)}")
+    if(N.na>0) note = note %^% "\n" %^%
         Glue("Valid <<italic N>> = {formatN(N-N.na)}")
   } else {
-    note="Total <i>N</i> = " %^% formatN(N)
-    if(N.na>0) note=note %^% "</p>\n<p>" %^%
+    note = "Total <i>N</i> = " %^% formatN(N)
+    if(N.na>0) note = note %^% "</p>\n<p>" %^%
         "Valid <i>N</i> = " %^% formatN(N-N.na)
   }
   print_table(output, nsmalls=c(0, nsmall), file=file,
@@ -352,62 +352,58 @@ Freq=function(x, varname, labels, sort="",
 #' Corr(airquality)
 #' Corr(airquality, p.adjust="bonferroni")
 #'
-#' d=as.data.table(psych::bfi)
+#' d = as.data.table(psych::bfi)
 #' d[, `:=`(
-#'   gender=as.factor(gender),
-#'   education=as.factor(education),
-#'   E=MEAN(d, "E", 1:5, rev=c(1,2), likert=1:6),
-#'   A=MEAN(d, "A", 1:5, rev=1, likert=1:6),
-#'   C=MEAN(d, "C", 1:5, rev=c(4,5), likert=1:6),
-#'   N=MEAN(d, "N", 1:5, likert=1:6),
-#'   O=MEAN(d, "O", 1:5, rev=c(2,5), likert=1:6)
+#'   gender = as.factor(gender),
+#'   education = as.factor(education),
+#'   E = MEAN(d, "E", 1:5, rev=c(1,2), likert=1:6),
+#'   A = MEAN(d, "A", 1:5, rev=1, likert=1:6),
+#'   C = MEAN(d, "C", 1:5, rev=c(4,5), likert=1:6),
+#'   N = MEAN(d, "N", 1:5, likert=1:6),
+#'   O = MEAN(d, "O", 1:5, rev=c(2,5), likert=1:6)
 #' )]
 #' Corr(d[, .(age, gender, education, E, A, C, N, O)])
 #'
 #' @seealso \code{\link{Describe}}
 #'
 #' @export
-Corr=function(data,
-              method="pearson",
-              p.adjust="none",
-              all.as.numeric=TRUE,
-              digits=2, nsmall=digits,
-              file=NULL,
-              plot=TRUE, plot.range=c(-1, 1),
-              plot.palette=NULL, plot.color.levels=201,
-              plot.file=NULL, plot.width=8, plot.height=6, plot.dpi=500) {
-  data.new=as.data.frame(data)
-  vars.not.numeric=c()
+Corr = function(data,
+                method="pearson",
+                p.adjust="none",
+                all.as.numeric=TRUE,
+                digits=2, nsmall=digits,
+                file=NULL,
+                plot=TRUE, plot.range=c(-1, 1),
+                plot.palette=NULL, plot.color.levels=201,
+                plot.file=NULL, plot.width=8, plot.height=6, plot.dpi=500) {
+  data.new = as.data.frame(data)
+  vars.not.numeric = c()
   if(all.as.numeric) {
     for(var in names(data.new)) {
       if(!is.numeric(data.new[[var]])) {
-        data.new[[var]]=as.numeric(data.new[[var]])
-        vars.not.numeric=c(vars.not.numeric, var)
+        data.new[[var]] = as.numeric(data.new[[var]])
+        vars.not.numeric = c(vars.not.numeric, var)
       }
     }
   }
 
-  cor=psych::corr.test(data.new, method=method,
-                       adjust=p.adjust,
-                       minlength=20)
-  COR=cor$ci["r"]
+  cor = psych::corr.test(data.new, method=method,
+                         adjust=p.adjust,
+                         minlength=20)
+  COR = cor$ci["r"]
   if(p.adjust=="none") {
-    COR$`[95% CI]`=paste0(
-      "[", formatF(cor$ci$lower, nsmall), ", ",
-      formatF(cor$ci$upper, nsmall), "]")
-    COR$pval=cor$ci$p
+    COR$`[95% CI]` = cc_ci(cor$ci$lower, cor$ci$upper, nsmall)
+    COR$pval = cor$ci$p
   } else {
-    COR$`[95% CI]`=paste0(
-      "[", formatF(cor$ci.adj$lower, nsmall), ", ",
-      formatF(cor$ci.adj$upper, nsmall), "]")
-    COR$pval=p.adjust(cor$ci$p, method=p.adjust)
+    COR$`[95% CI]` = cc_ci(cor$ci.adj$lower, cor$ci.adj$upper, nsmall)
+    COR$pval = p.adjust(cor$ci$p, method=p.adjust)
   }
   if(inherits(cor$n, "matrix"))
-    Ns=cor$n[lower.tri(cor$n)]
+    Ns = cor$n[lower.tri(cor$n)]
   else
-    Ns=cor$n
-  COR$r=formatF(COR$r, nsmall)
-  COR$N=Ns
+    Ns = cor$n
+  COR$r = formatF(COR$r, nsmall)
+  COR$N = Ns
 
   if(length(vars.not.numeric)>0) {
     Print("<<yellow NOTE: `{paste(vars.not.numeric, collapse='`, `')}` transformed to numeric.>>")
@@ -416,22 +412,22 @@ Corr=function(data,
 
   if(plot) {
     if(is.null(plot.palette))
-      plot.palette=c("#B52127", "white", "#2171B5")
+      plot.palette = c("#B52127", "white", "#2171B5")
     if(!is.null(plot.file)) {
       grDevices::png(filename=plot.file, width=plot.width, height=plot.height, units="in", res=plot.dpi)
     }
     try({
-      plot.error=TRUE
+      plot.error = TRUE
       cor_plot(r=cor$r, adjust="none", nsmall=nsmall,
                numbers=TRUE, zlim=plot.range,
                diag=FALSE, xlas=2, n=plot.color.levels,
                pval=cor$p, stars=TRUE,
                alpha=1, gr=grDevices::colorRampPalette(plot.palette),
                main="Correlation Matrix")
-      plot.error=FALSE
+      plot.error = FALSE
     }, silent=TRUE)
     if(plot.error) {
-      warning=Glue("
+      warning = Glue("
         Plot is NOT successfully displayed in the RStudio `Plots` Pane.
         Please check if the `Plots` Pane of your RStudio is too small.
         You should enlarge the `Plots` Pane (and/or clear all plots).")
@@ -445,8 +441,8 @@ Corr=function(data,
     }
     if(!is.null(plot.file)) {
       grDevices::dev.off()
-      plot.file=str_split(plot.file, "/", simplify=TRUE)
-      plot.path=paste0(getwd(), '/', plot.file[length(plot.file)])
+      plot.file = str_split(plot.file, "/", simplify=TRUE)
+      plot.path = paste0(getwd(), '/', plot.file[length(plot.file)])
       Print("<<green \u221a>> Plot saved to <<blue '{plot.path}'>>")
       cat("\n")
     }
@@ -460,49 +456,49 @@ Corr=function(data,
     cat("\n")
   } else {
     Print("Descriptive Statistics and Correlation Matrix:")
-    cor.mat=matrix(formatF(cor$r, nsmall),
-                   nrow=nrow(cor$r),
-                   dimnames=list(rownames(cor$r),
-                                 colnames(cor$r)))
-    cor.sig=sig.trans(cor$p)
+    cor.mat = matrix(formatF(cor$r, nsmall),
+                     nrow=nrow(cor$r),
+                     dimnames=list(rownames(cor$r),
+                                   colnames(cor$r)))
+    cor.sig = sig.trans(cor$p)
     if(p.adjust=="none") {
       for(i in 1:nrow(cor.mat))
         for(j in i:ncol(cor.mat))
-          cor.mat[i,j]=NA
+          cor.mat[i,j] = NA
     } else {
       for(i in 1:nrow(cor.mat))
-        cor.mat[i,i]=NA
+        cor.mat[i,i] = NA
     }
     for(i in 1:nrow(cor.mat)) {
       for(j in 1:ncol(cor.mat)) {
-        cor.mat[i,j]=str_replace_all(cor.mat[i,j], "0\\.", ".")
+        cor.mat[i,j] = str_replace_all(cor.mat[i,j], "0\\.", ".")
         if(!is.na(cor.mat[i,j])) {
           if(as.numeric(cor.mat[i,j])>0)
-            cor.mat[i,j]=paste0("&ensp;", str_trim(cor.mat[i,j]))
+            cor.mat[i,j] = paste0("&ensp;", str_trim(cor.mat[i,j]))
           if(grepl("\\*", cor.sig[i,j]))
-            cor.mat[i,j]=paste0(cor.mat[i,j], "<sup>", str_replace_all(cor.sig[i,j], "\\s", "&ensp;"), "</sup>")
+            cor.mat[i,j] = paste0(cor.mat[i,j], "<sup>", str_replace_all(cor.sig[i,j], "\\s", "&ensp;"), "</sup>")
           else
-            cor.mat[i,j]=paste0(cor.mat[i,j], "<sup>&ensp;&ensp;&ensp;</sup>")
+            cor.mat[i,j] = paste0(cor.mat[i,j], "<sup>&ensp;&ensp;&ensp;</sup>")
         }
       }
     }
     for(i in 1:nrow(cor.mat))
-      cor.mat[i,i]="&ensp;&nbsp;\u2014"
-    des.cor=cbind(Variable=1:nrow(cor.mat) %^% ". " %^% row.names(cor.mat),
-                  Describe(data, file="NOPRINT")$desc[c("Mean", "SD")],
-                  cor.mat)
-    names(des.cor)=c("Variable", "<i>M</i>", "<i>SD</i>", 1:ncol(cor.mat))
-    if(p.adjust=="none") des.cor[ncol(des.cor)]=NULL
-    COR.new=COR
-    COR.new$Pairs=row.names(COR)
-    COR.new$`r [95% CI]`=paste(COR$r, COR$`[95% CI]`) %>%
+      cor.mat[i,i] = "&ensp;&nbsp;\u2014"
+    des.cor = cbind(Variable=1:nrow(cor.mat) %^% ". " %^% row.names(cor.mat),
+                    Describe(data, file="NOPRINT")$desc[c("Mean", "SD")],
+                    cor.mat)
+    names(des.cor) = c("Variable", "<i>M</i>", "<i>SD</i>", 1:ncol(cor.mat))
+    if(p.adjust=="none") des.cor[ncol(des.cor)] = NULL
+    COR.new = COR
+    COR.new$Pairs = row.names(COR)
+    COR.new$`r [95% CI]` = paste(COR$r, COR$`[95% CI]`) %>%
       str_replace_all("-", "\u2013") %>%
       str_replace_all("0\\.", ".") %>%
       str_replace_all("^ \\.", "&ensp;.")
-    COR.new$p=p.trans(COR$pval)
-    COR.new=COR.new[c("Pairs", "r [95% CI]", "p", "N")]
-    names(COR.new)=c("Pairs", "<i>r</i> [95% CI]", "<i>p</i>", "<i>N</i>")
-    cor.ci=paste0(
+    COR.new$p = p.trans(COR$pval)
+    COR.new = COR.new[c("Pairs", "r [95% CI]", "p", "N")]
+    names(COR.new) = c("Pairs", "<i>r</i> [95% CI]", "<i>p</i>", "<i>N</i>")
+    cor.ci = paste0(
       "<p><br/><br/></p>",
       "<p><b>Table 2. Correlations and 95% Confidence Intervals.</b></p>",
       df_to_html(
@@ -770,13 +766,13 @@ cor_plot <- function (r, numbers = TRUE, colors = TRUE, n = 51, main = NULL,
 #' cor_diff(r1=0.20, r2=0.45, n=100, rcov=0.80)
 #'
 #' @export
-cor_diff=function(r1, n1, r2, n2, n=NULL, rcov=NULL) {
+cor_diff = function(r1, n1, r2, n2, n=NULL, rcov=NULL) {
   if(is.null(rcov)) {
     # independent rs
-    z1=atanh(r1)
-    z2=atanh(r2)
-    zdiff=(z1-z2)/sqrt(1/(n1-3)+1/(n2-3))
-    p=p.z(zdiff)
+    z1 = atanh(r1)
+    z2 = atanh(r2)
+    zdiff = (z1-z2) / sqrt(1/(n1-3) + 1/(n2-3))
+    p = p.z(zdiff)
     Print("
     <<italic r>>1 = {formatF(r1)} (<<italic N>> = {formatN(n1)})
     <<italic r>>2 = {formatF(r2)} (<<italic N>> = {formatN(n2)})
@@ -784,9 +780,9 @@ cor_diff=function(r1, n1, r2, n2, n=NULL, rcov=NULL) {
     ")
   } else {
     # nonindependent rs
-    R=(1-r1^2-r2^2-rcov^2)+2*r1*r2*rcov
-    tdiff=(r1-r2)*sqrt((n-1)*(1+rcov)/(2*R*(n-1)/(n-3)+(r1+r2)^2*(1-rcov)^3/4))
-    p=p.t(tdiff, n-3)
+    R = (1-r1^2-r2^2-rcov^2) + 2*r1*r2*rcov
+    tdiff = (r1-r2) * sqrt((n-1)*(1+rcov) / (2*R*(n-1)/(n-3) + (r1+r2)^2*(1-rcov)^3/4))
+    p = p.t(tdiff, n-3)
     Print("
     <<italic r>>1 = {formatF(r1)}
     <<italic r>>2 = {formatF(r2)}
@@ -852,12 +848,12 @@ cor_diff=function(r1, n1, r2, n2, n=NULL, rcov=NULL) {
 #'
 #' @examples
 #' ## Demo data ##
-#' d1=between.3
-#' d1$Y1=d1$SCORE  # shorter name for convenience
-#' d1$Y2=rnorm(32)  # random variable
-#' d1$B=factor(d1$B, levels=1:2, labels=c("Low", "High"))
-#' d1$C=factor(d1$C, levels=1:2, labels=c("M", "F"))
-#' d2=within.1
+#' d1 = between.3
+#' d1$Y1 = d1$SCORE  # shorter name for convenience
+#' d1$Y2 = rnorm(32)  # random variable
+#' d1$B = factor(d1$B, levels=1:2, labels=c("Low", "High"))
+#' d1$C = factor(d1$C, levels=1:2, labels=c("M", "F"))
+#' d2 = within.1
 #'
 #' ## One-sample t-test ##
 #' TTEST(d1, "SCORE")
@@ -885,7 +881,7 @@ cor_diff=function(r1, n1, r2, n2, n=NULL, rcov=NULL) {
 #'   # In this example, the true point estimate of Cohen's d = 3.00
 #'   # and its 95% CI should be equal to 95% CI of mean difference.
 #'
-#'   data=data.frame(X=rep(1:2, each=3), Y=1:6)
+#'   data = data.frame(X=rep(1:2, each=3), Y=1:6)
 #'   data  # simple demo data
 #'
 #'   TTEST(data, y="Y", x="X")
@@ -926,45 +922,45 @@ cor_diff=function(r1, n1, r2, n2, n=NULL, rcov=NULL) {
 #' @seealso \code{\link{MANOVA}}, \code{\link{EMMEANS}}
 #'
 #' @export
-TTEST=function(data, y, x=NULL,
-               paired=FALSE,
-               var.equal=TRUE,
-               mean.diff=TRUE,
-               test.value=0,
-               test.sided=c("=", "<", ">"),
-               factor.rev=TRUE,
-               bayes.prior="medium",
-               digits=2, nsmall=digits,
-               file=NULL) {
-  data=as.data.frame(data)
+TTEST = function(data, y, x=NULL,
+                 paired=FALSE,
+                 var.equal=TRUE,
+                 mean.diff=TRUE,
+                 test.value=0,
+                 test.sided=c("=", "<", ">"),
+                 factor.rev=TRUE,
+                 bayes.prior="medium",
+                 digits=2, nsmall=digits,
+                 file=NULL) {
+  data = as.data.frame(data)
 
   if(paired) {
     if(!is.null(x))
       stop("For paired-samples t-test, x should not be used.", call.=TRUE)
     if(length(y)%%2==1)
       stop("For paired-samples t-test, y should be a vector of 2, 4, 6, ... variables.", call.=TRUE)
-    type="Paired-Samples t-test"
-    mu=ifelse(factor.rev, "\u03bc2 - \u03bc1", "\u03bc1 - \u03bc2")
-    y=split(y, rep(1:(length(y)/2), each=2))
+    type = "Paired-Samples t-test"
+    mu = ifelse(factor.rev, "\u03bc2 - \u03bc1", "\u03bc1 - \u03bc2")
+    y = split(y, rep(1:(length(y)/2), each=2))
   } else {
     if(is.null(x)) {
-      type="One-Sample t-test"
-      mu="\u03bc"
+      type = "One-Sample t-test"
+      mu = "\u03bc"
     } else {
-      type="Independent-Samples t-test"
-      mu=ifelse(factor.rev, "\u03bc2 - \u03bc1", "\u03bc1 - \u03bc2")
+      type = "Independent-Samples t-test"
+      mu = ifelse(factor.rev, "\u03bc2 - \u03bc1", "\u03bc1 - \u03bc2")
       if(test.value!=0)
         message("Test value (mu) for Bayes test is reset to 0.")
     }
   }
 
-  if(length(test.sided)>1) test.sided="="
+  if(length(test.sided)>1) test.sided = "="
   if(test.sided %notin% c("=", "<", ">"))
     stop("test.sided should be one of \"=\", \"<\", or \">\"", call.=TRUE)
-  hypo=switch(test.sided,
-              `=`=Glue("two-sided ({mu} \u2260 {test.value})"),
-              `<`=Glue("one-sided ({mu} < {test.value})"),
-              `>`=Glue("one-sided ({mu} > {test.value})"))
+  hypo = switch(test.sided,
+                `=`=Glue("two-sided ({mu} \u2260 {test.value})"),
+                `<`=Glue("one-sided ({mu} < {test.value})"),
+                `>`=Glue("one-sided ({mu} > {test.value})"))
 
   ## Info
   Print("
@@ -976,34 +972,34 @@ TTEST=function(data, y, x=NULL,
   ")
 
   ## Test
-  nmsd=data.frame()
-  lev=data.frame()
-  res=data.frame()
+  nmsd = data.frame()
+  lev = data.frame()
+  res = data.frame()
   for(yi in y) {
     if(is.null(x)) {
-      res.list=ttest(data, yi, NULL, paired, var.equal,
-                     test.value, test.sided, factor.rev, bayes.prior)
-      res=rbind(res, res.list$res)
-      nmsd=rbind(nmsd, res.list$nmsd)
+      res.list = ttest(data, yi, NULL, paired, var.equal,
+                       test.value, test.sided, factor.rev, bayes.prior)
+      res = rbind(res, res.list$res)
+      nmsd = rbind(nmsd, res.list$nmsd)
       if(!is.null(res.list$levene))
-        lev=rbind(lev, res.list$levene)
+        lev = rbind(lev, res.list$levene)
     } else {
       for(xi in x) {
-        res.list=ttest(data, yi, xi, paired, var.equal,
-                       test.value, test.sided, factor.rev, bayes.prior)
-        res=rbind(res, res.list$res)
-        nmsd=rbind(nmsd, res.list$nmsd)
+        res.list = ttest(data, yi, xi, paired, var.equal,
+                         test.value, test.sided, factor.rev, bayes.prior)
+        res = rbind(res, res.list$res)
+        nmsd = rbind(nmsd, res.list$nmsd)
         if(!is.null(res.list$levene))
-          lev=rbind(lev, res.list$levene)
+          lev = rbind(lev, res.list$levene)
       }
     }
   }
 
   ## Print (nmsd)
-  nmsd$MeanSD=paste0(formatF(nmsd$Mean, nsmall), " (",
+  nmsd$MeanSD = paste0(formatF(nmsd$Mean, nsmall), " (",
                      formatF(nmsd$S.D., nsmall), ")")
-  names(nmsd)[length(nmsd)]="Mean (S.D.)"
-  nmsd$Mean=nmsd$S.D.=NULL
+  names(nmsd)[length(nmsd)] = "Mean (S.D.)"
+  nmsd$Mean = nmsd$S.D. = NULL
   Print("Descriptives:")
   print_table(nmsd, row.names=FALSE, nsmalls=0)
   cat("\n")
@@ -1019,30 +1015,26 @@ TTEST=function(data, y, x=NULL,
   }
 
   ## Print (t-test)
-  RES=res[,1:3]  # t, df, pval
-  RES$Diff=paste0(formatF(res$diff, nsmall), " [",
-                  formatF(res$llci, nsmall), ", ",
-                  formatF(res$ulci, nsmall), "]")
-  RES$Cohen=paste0(formatF(res$Cohen_d, nsmall), " [",
-                   formatF(res$LLCI, nsmall), ", ",
-                   formatF(res$ULCI, nsmall), "]")
-  RES$BF10=sprintf(Glue("%.{nsmall}e"), res$BF10)
+  RES = res[,1:3]  # t, df, pval
+  RES$Diff = cc_m_ci(res$diff, res$llci, res$ulci, nsmall)
+  RES$Cohen = cc_m_ci(res$Cohen_d, res$LLCI, res$ULCI, nsmall)
+  RES$BF10 = sprintf(Glue("%.{nsmall}e"), res$BF10)
   if(!is.null(file)) {
-    RES$Diff=str_replace_all(RES$Diff, "-", "\u2013")
-    RES$Cohen=str_replace_all(RES$Cohen, "-", "\u2013")
-    RES$BF10=str_replace_all(RES$BF10, "-", "\u2013")
-    names(RES)=c("<i>t</i>",
+    RES$Diff = str_replace_all(RES$Diff, "-", "\u2013")
+    RES$Cohen = str_replace_all(RES$Cohen, "-", "\u2013")
+    RES$BF10 = str_replace_all(RES$BF10, "-", "\u2013")
+    names(RES) = c("<i>t</i>",
                  "<i>df</i>",
                  "<i>p</i>",
                  "Difference [95% CI]",
                  "Cohen\u2019s <i>d</i> [95% CI]",
                  "BF<sub>10</sub>")
   } else {
-    names(RES)[4:5]=c("Difference [95% CI]",
-                      "Cohen\u2019s d [95% CI]")
+    names(RES)[4:5] = c("Difference [95% CI]",
+                        "Cohen\u2019s d [95% CI]")
   }
   if(mean.diff==FALSE)
-    RES[,4]=NULL
+    RES[,4] = NULL
   print_table(
     RES,
     nsmalls=c(nsmall, ifelse(var.equal, 0, nsmall), 0, 0, 0, 0, 0),
@@ -1060,141 +1052,142 @@ TTEST=function(data, y, x=NULL,
 
 
 ## one y and one x
-ttest=function(data, y, x=NULL,
-               paired=FALSE,
-               var.equal=TRUE,
-               test.value=0,
-               test.sided="=",
-               factor.rev=TRUE,
-               bayes.prior="medium") {
+ttest = function(data, y, x=NULL,
+                 paired=FALSE,
+                 var.equal=TRUE,
+                 test.value=0,
+                 test.sided="=",
+                 factor.rev=TRUE,
+                 bayes.prior="medium") {
   ## Data
-  data=na.omit(data[c(y, x)])
-  alternative=switch(test.sided,
-                     `=`="two.sided",
-                     `<`="less",
-                     `>`="greater")
+  data = na.omit(data[c(y, x)])
+  alternative = switch(test.sided,
+                       `=`="two.sided",
+                       `<`="less",
+                       `>`="greater")
   if(alternative=="less")
-    nullInterval=c(-Inf, 0)
+    nullInterval = c(-Inf, 0)
   else if(alternative=="greater")
-    nullInterval=c(0, Inf)
+    nullInterval = c(0, Inf)
   else
-    nullInterval=NULL
+    nullInterval = NULL
 
   ## Prepare
   if(paired) {
-    nmsd=data.frame(Variable=c(y[1], y[2]),
-                    Mean=c(mean(data[[y[1]]]), mean(data[[y[2]]])),
-                    S.D.=c(sd(data[[y[1]]]), sd(data[[y[2]]])),
-                    N=nrow(data))
+    nmsd = data.frame(Variable=c(y[1], y[2]),
+                      Mean=c(mean(data[[y[1]]]), mean(data[[y[2]]])),
+                      S.D.=c(sd(data[[y[1]]]), sd(data[[y[2]]])),
+                      N=nrow(data))
     if(factor.rev) {
-      formula=as.formula(Glue("Pair({y[2]}, {y[1]}) ~ 1"))
-      label=paste(y[2], "-", y[1])
+      formula = as.formula(Glue("Pair({y[2]}, {y[1]}) ~ 1"))
+      label = paste(y[2], "-", y[1])
     } else {
-      formula=as.formula(Glue("Pair({y[1]}, {y[2]}) ~ 1"))
-      label=paste(y[1], "-", y[2])
+      formula = as.formula(Glue("Pair({y[1]}, {y[2]}) ~ 1"))
+      label = paste(y[1], "-", y[2])
     }
-    Y="Paired"
-    X=""
-    y1=data[[y[1]]]
-    y2=data[[y[2]]]
-    sd.pooled=sd(y1-y2)
-    mu.BF=test.value
+    Y = "Paired"
+    X = ""
+    y1 = data[[y[1]]]
+    y2 = data[[y[2]]]
+    sd.pooled = sd(y1-y2)
+    mu.BF = test.value
   } else {
     if(is.null(x)) {
-      formula=as.formula(Glue("{y} ~ 1"))
-      nmsd=data.frame(Variable=y,
-                      Mean=mean(data[[y]]),
-                      S.D.=sd(data[[y]]),
-                      N=nrow(data))
-      label=paste(y, "-", test.value)
-      Y=y
-      X=""
-      y1=data[[y]]
-      y2=NULL
-      sd.pooled=sd(y1)
-      mu.BF=test.value
+      formula = as.formula(Glue("{y} ~ 1"))
+      nmsd = data.frame(Variable=y,
+                        Mean=mean(data[[y]]),
+                        S.D.=sd(data[[y]]),
+                        N=nrow(data))
+      label = paste(y, "-", test.value)
+      Y = y
+      X = ""
+      y1 = data[[y]]
+      y2 = NULL
+      sd.pooled = sd(y1)
+      mu.BF = test.value
     } else {
-      formula=as.formula(Glue("{y} ~ {x}"))
-      data[[x]]=as.factor(data[[x]])
+      formula = as.formula(Glue("{y} ~ {x}"))
+      data[[x]] = as.factor(data[[x]])
       if(nlevels(data[[x]])!=2)
         stop(Glue("Levels of the factor \"{x}\" should be 2."), call.=TRUE)
-      nmsd=plyr::ddply(
+      nmsd = plyr::ddply(
         .data=data,
         .variables=plyr::as.quoted(x),
         .fun=summarise,
         bruceR.Mean=mean(!!sym(y)),
         bruceR.S.D.=sd(!!sym(y)),
         bruceR.N=length(!!sym(y)))
-      names(nmsd)=c("Level", "Mean", "S.D.", "N")
-      nmsd=cbind(data.frame(Variable=y,
-                            Factor=x),
-                 as.data.frame(nmsd))
-      if(factor.rev) data[[x]]=forcats::fct_rev(data[[x]])
-      label=paste(levels(data[[x]]), collapse=" - ")
-      Y=y
-      X=x%^%" "
-      xlevels=levels(data[[x]])
-      y1=data[which(data[[x]]==xlevels[1]), y]
-      y2=data[which(data[[x]]==xlevels[2]), y]
-      df1=length(y1)-1
-      df2=length(y2)-1
+      names(nmsd) = c("Level", "Mean", "S.D.", "N")
+      nmsd = cbind(data.frame(Variable=y,
+                              Factor=x),
+                   as.data.frame(nmsd))
+      if(factor.rev) data[[x]] = forcats::fct_rev(data[[x]])
+      label = paste(levels(data[[x]]), collapse=" - ")
+      Y = y
+      X = x %^% " "
+      xlevels = levels(data[[x]])
+      y1 = data[which(data[[x]]==xlevels[1]), y]
+      y2 = data[which(data[[x]]==xlevels[2]), y]
+      df1 = length(y1)-1
+      df2 = length(y2)-1
       # https://github.com/jamovi/jmv/blob/master/R/ttestis.b.R
       if(var.equal)
-        sd.pooled=sqrt((var(y1)*df1+var(y2)*df2)/(df1+df2))
+        sd.pooled = sqrt((var(y1)*df1+var(y2)*df2) / (df1+df2))
       else
-        sd.pooled=sqrt((var(y1)+var(y2))/2)
-      mu.BF=0
+        sd.pooled = sqrt((var(y1)+var(y2)) / 2)
+      mu.BF = 0
     }
   }
 
   ## Test
-  res=stats::t.test(formula=formula,
-                    data=data,
-                    var.equal=var.equal,
-                    mu=test.value,
-                    alternative=alternative)
-  t=res[["statistic"]]
-  df=res[["parameter"]]
-  pval=res[["p.value"]]
-  est=res[["estimate"]]
-  diff=ifelse(length(est)==1, est, est[1]-est[2])-test.value
-  llci=res[["conf.int"]][1]-test.value
-  ulci=res[["conf.int"]][2]-test.value
-  Cohen_d=diff/sd.pooled
-  LLCI=llci/sd.pooled
-  ULCI=ulci/sd.pooled
-  BF=BayesFactor::ttestBF(x=y1, y=y2,
-                          paired=paired,
-                          mu=mu.BF,
-                          nullInterval=nullInterval,
-                          rscale=bayes.prior)
-  BF=BayesFactor::extractBF(BF)
-  RES=data.frame(Y=Y,
-                 Comparison=X%^%"("%^%label%^%")",
-                 t=t,
-                 df=df,
-                 pval=pval,
-                 diff=diff,
-                 llci=llci,
-                 ulci=ulci,
-                 Cohen_d=Cohen_d,
-                 LLCI=LLCI,
-                 ULCI=ULCI,
-                 BF10=BF$bf[1],
-                 Error=BF$error[1])
-  row.names(RES)=RES$Y %^% ": " %^% RES$Comparison
+  res = stats::t.test(formula=formula,
+                      data=data,
+                      var.equal=var.equal,
+                      mu=test.value,
+                      alternative=alternative)
+  t = res[["statistic"]]
+  df = res[["parameter"]]
+  pval = res[["p.value"]]
+  est = res[["estimate"]]
+  diff = ifelse(length(est)==1, est, est[1]-est[2])-test.value
+  llci = res[["conf.int"]][1]-test.value
+  ulci = res[["conf.int"]][2]-test.value
+  Cohen_d = diff/sd.pooled
+  LLCI = llci/sd.pooled
+  ULCI = ulci/sd.pooled
+  BF = BayesFactor::ttestBF(x=y1, y=y2,
+                            paired=paired,
+                            mu=mu.BF,
+                            nullInterval=nullInterval,
+                            rscale=bayes.prior)
+  BF = BayesFactor::extractBF(BF)
+  RES = data.frame(
+    Y=Y,
+    Comparison=X %^% "(" %^% label %^% ")",
+    t=t,
+    df=df,
+    pval=pval,
+    diff=diff,
+    llci=llci,
+    ulci=ulci,
+    Cohen_d=Cohen_d,
+    LLCI=LLCI,
+    ULCI=ULCI,
+    BF10=BF$bf[1],
+    Error=BF$error[1])
+  row.names(RES) = RES$Y %^% ": " %^% RES$Comparison
 
   ## Check
   if(is.null(x)) {
-    levene=NULL
+    levene = NULL
   } else {
-    lev=car::leveneTest(formula, data, center=mean)
-    levene=cbind(lev[1, "F value"],
-                 lev[1, "Df"],
-                 lev[2, "Df"],
-                 lev[1, "Pr(>F)"]) %>% as.data.frame()
-    names(levene)=c("Levene\u2019s F", "df1", "df2", "pval")
-    row.names(levene)=row.names(RES)
+    lev = car::leveneTest(formula, data, center=mean)
+    levene = cbind(lev[1, "F value"],
+                   lev[1, "Df"],
+                   lev[2, "Df"],
+                   lev[1, "Pr(>F)"]) %>% as.data.frame()
+    names(levene) = c("Levene\u2019s F", "df1", "df2", "pval")
+    row.names(levene) = row.names(RES)
   }
 
   return(list(nmsd=nmsd, levene=levene, res=RES[,-1:-2]))
